### Running E2E Tests

You will need to have the following environment variables defined.

| name                            | value                                                                                                            | description                                                                                                                                                  | sensitive? | source |
|---------------------------------|------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------|------------|--------|
| `CLIENT_TENANT`                 | eg. `osdu`                                                                                                       | Client tenant used for testing                                                                                                                               | no         | -      |
| `OSDU_TENANT`                   | eg. `osdu`                                                                                                       | OSDU tenant used for testing                                                                                                                                 | no         | -      |
| `GROUP_ID`                      | eg. `group`                                                                                                      | Group ID used for testing. Group id, used in storage record ACL. Full group will be "data.default.viewers@{{data-partition-id}}.{{group_id}}"                | no         | -      |
| `TOPIC_ID`                      | eg. `records-changed`                                                                                            | Topic ID                                                                                                                                                     | no         | -      |
| `HMAC_SECRET`                   | eg. `123456789`                                                                                                  | String in hex , must match pattern ^[a-zA-Z0-9]{8,30}+$ & be in register variable SUBSCRIBER_SECRET                                                          | yes        | -      |
| `NOTIFICATION_BASE_URL`         | eg. `https://osdu.core-dev.gcp.gnrg-osdu.projects.epam.com/api/notification/v1/`                                 | Endpoint of notification service                                                                                                                             | no         | -      |
| `REGISTER_BASE_URL`             | eg. `https://osdu.core-dev.gcp.gnrg-osdu.projects.epam.com/api/register/v1`                                      | Endpoint of register service                                                                                                                                 | no         | -      |
| `REGISTER_CUSTOM_PUSH_URL_HMAC` | eg. `https://osdu.core-dev.gcp.gnrg-osdu.projects.epam.com/api/register/v1/test/challenge/hmac-integration-test` | Endpoint of register custom push URL HMAC                                                                                                                    | no         | -      |
| `LEGAL_HOST`                    | eg. `https://osdu.core-dev.gcp.gnrg-osdu.projects.epam.com/api/legal/v1`                                         | Endpoint of legal service                                                                                                                                    | no         | -      |
| `STORAGE_HOST`                  | eg. `https://osdu.core-dev.gcp.gnrg-osdu.projects.epam.com/api/storage/v2`                                       | Endpoint of storage service                                                                                                                                  | no         | -      |
| `GSA_TEST_ENABLED`              | eg. `true` or `false`                                                                                            | Enabler for GSA tests                                                                                                                                        | no         | -      |
Authentication can be provided as OIDC config:

| name                                           | value                                   | description                                           | sensitive? | source |
|------------------------------------------------|-----------------------------------------|-------------------------------------------------------|------------|--------|
| `TEST_DE_ADMIN_OPENID_PROVIDER_CLIENT_ID`      | `********`                              | Service account client id which has admins api access | yes        | -      |
| `TEST_DE_ADMIN_OPENID_PROVIDER_CLIENT_SECRET`  | `********`                              | Service account secret which has admins api access    | yes        | -      |
| `TEST_DE_EDITOR_OPENID_PROVIDER_CLIENT_ID`     | `********`                              | Service account client id which has editor api access | yes        | -      |
| `TEST_DE_EDITOR_OPENID_PROVIDER_CLIENT_SECRET` | `********`                              | Service account secret which has editor api access    | yes        | -      |
| `TEST_DE_OPS_OPENID_PROVIDER_CLIENT_ID`        | `********`                              | Service account client id which has full api access   | yes        | -      |
| `TEST_DE_OPS_OPENID_PROVIDER_CLIENT_SECRET`    | `********`                              | Service account secret which has full api access      | yes        | -      |
| `TEST_NO_ACCESS_OPENID_PROVIDER_CLIENT_ID`     | `********`                              | Service account client id which has not api access    | yes        | -      |
| `TEST_NO_ACCESS_OPENID_PROVIDER_CLIENT_SECRET` | `********`                              | Service account secret which has not api access       | yes        | -      |
| `TEST_OPENID_PROVIDER_URL`                     | `https://keycloak.com/auth/realms/osdu` | OpenID provider url                                   | yes        | -      |

Or tokens can be used directly from env variables:

| name                   | value      | description          | sensitive? | source |
|------------------------|------------|----------------------|------------|--------|
| `DE_ADMIN_USER_TOKEN`  | `********` | DE_ADMIN_USER Token  | yes        | -      |
| `DE_EDITOR_USER_TOKEN` | `********` | DE_EDITOR_USER Token | yes        | -      |
| `DE_OPS_USER_TOKEN`    | `********` | DE_OPS_USER Token    | yes        | -      |
| `NO_ACCESS_USER_TOKEN` | `********` | NO_ACCESS_USER Token | yes        | -      |

**Entitlements configuration for integration accounts**

| DE_OPS_TESTER                                                                           | DE_ADMIN_TESTER                                                                       | DE_EDITOR_TESTER                                                    | DE_NO_ACCESS_TESTER                      |
|-----------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------|---------------------------------------------------------------------|------------------------------------------|
| notification.pubsub<br/>service.entitlements.user<br/>users<br/>users.datalake.ops</br> | service.entitlements.user<br/>users<br/>users.datalake.admins</br>service.legal.admin | service.entitlements.user<br/>users<br/>users.datalake.editors</br> | service.entitlements.user<br/>users<br/> |

Above variables should be configured in the release pipeline to run integration tests. You should also replace them with proper values if you wish to run tests locally.

### Commands to run tests
Execute following command to build code and run all the integration tests:

 ```bash
 # Note: this assumes that the environment variables for acceptance tests as outlined
 #       above are already exported in your environment.
 # build + install integration test core
 $ (cd notification-acceptance-test && mvn clean verify)
 ```

## License

Copyright © Google LLC

Copyright © EPAM Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

[http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
