/*
  Copyright 2002-2022 Google LLC
  Copyright 2002-2022 EPAM Systems, Inc

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package org.opengroup.osdu.notification.util;

import com.google.common.base.Strings;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class TokenTestUtils extends TestUtils {

  public static final String DE_ADMIN_USER_TOKEN = "DE_ADMIN_USER_TOKEN";
  public static final String DE_EDITOR_USER_TOKEN = "DE_EDITOR_USER_TOKEN";
  public static final String DE_OPS_USER_TOKEN = "DE_OPS_USER_TOKEN";
  public static final String NO_ACCESS_USER_TOKEN = "NO_ACCESS_USER_TOKEN";
  private OpenIDTokenProvider tokenProvider;

  public TokenTestUtils() {
    adminToken = System.getProperty(DE_ADMIN_USER_TOKEN, System.getenv(DE_ADMIN_USER_TOKEN));
    editorToken = System.getProperty(DE_EDITOR_USER_TOKEN, System.getenv(DE_EDITOR_USER_TOKEN));
    opsToken = System.getProperty(DE_OPS_USER_TOKEN, System.getenv(DE_OPS_USER_TOKEN));
    noAccessToken = System.getProperty(NO_ACCESS_USER_TOKEN, System.getenv(NO_ACCESS_USER_TOKEN));

    if (Strings.isNullOrEmpty(adminToken) || Strings.isNullOrEmpty(editorToken) || Strings.isNullOrEmpty(opsToken) || Strings.isNullOrEmpty(noAccessToken)) {
      tokenProvider = new OpenIDTokenProvider();
      adminToken = getAdminToken();
      editorToken = getEditorToken();
      opsToken = getOpsToken();
      noAccessToken = getNoAccessToken();
    }
  }

  @Override
  public synchronized String getOpsToken() {
    return "Bearer " + tokenProvider.getOpsAccessToken();
  }

  @Override
  public synchronized String getAdminToken() {
    return "Bearer " + tokenProvider.getAdminAccessToken();
  }

  @Override
  public synchronized String getEditorToken() {
    return "Bearer " + tokenProvider.getEditorAccessToken();
  }

  @Override
  public synchronized String getNoAccessToken() {
    return "Bearer " + tokenProvider.getNoAccessToken();
  }
}