/* Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.opengroup.osdu.notification.subscriptions;

import com.google.gson.JsonArray;
import org.apache.commons.lang3.tuple.Pair;
import org.opengroup.osdu.core.common.Constants;
import org.opengroup.osdu.core.common.model.entitlements.Acl;
import org.opengroup.osdu.core.common.model.legal.Legal;
import org.opengroup.osdu.core.common.model.storage.Record;

import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class RecordUtils {

    private static final String domain = System.getProperty("DOMAIN", System.getenv("DOMAIN"));

    public static Record[] createRecordsWithReference(int recordsCount, String id, String kind, String legalTag, boolean isTestPartition) {

        Record[] records = new Record[recordsCount];

        for (int i = 0; i < recordsCount; i++) {

            Map<String, Object> data = new HashMap<>();
            String specificId = id + i;
            data.put("name", specificId);
            Map<String, Object>[] metaBlocks = new Map[0];

            Record record = getRecordWithInputData(specificId, kind, legalTag, data, isTestPartition);
            record.setMeta(metaBlocks);

            records[i] = record;
        }

        return records;
    }

    private static Record getRecordWithInputData(String id, String kind, String legalTag, Map<String, Object> data, boolean isTestPartition) {
        Record record = getDefaultRecord(id, kind, legalTag, isTestPartition);
        record.setData(data);
        return record;
    }

    public static String[] getDefaultAcls(boolean isTestPartition) {
        return new String[]{String.format("data.test1@%s", getAclSuffix(isTestPartition))};
    }

    private static Record getDefaultRecord(String id, String kind, String legalTag, boolean isTestPartition) {
        return getDefaultRecordFromAcl(id, kind, legalTag, getDefaultAcls(isTestPartition));
    }

    private static Record getDefaultRecordFromAcl(String id, String kind, String legalTag, String[] acls) {
        Pair<Acl, Legal> pair = getAclAndLegal(acls, legalTag, "BR");

        Record record = new Record();
        record.setAcl(pair.getLeft());
        record.setLegal(pair.getRight());
        record.setId(id);
        record.setKind(kind);
        return record;
    }

    public static Pair<Acl, Legal> getAclAndLegal(String[] acls, String legalTags, String... countries) {
        Acl acl = new Acl();
        acl.setOwners(acls);
        acl.setViewers(acls);

        Set<String> ordc = new HashSet<>();
        Collections.addAll(ordc, countries);
        Set<String> tags =  new HashSet<>();
        tags.add(legalTags);

        Legal legal = new Legal();
        legal.setLegaltags(tags);
        legal.setOtherRelevantDataCountries(ordc);

        return Pair.of(acl, legal);
    }

    public static String getAclSuffix(boolean isTestPartition) {
        return String.format("%s.%s", TenantUtils.getTenantName(isTestPartition), domain);
    }

}
